==> HTTP-Throwable-0.019.tar.gz: HTTP-Throwable-0.019/lib/HTTP/Throwable/Role/Status/GatewayTimeout.pm <==
package HTTP::Throwable::Role::Status::GatewayTimeout;
BEGIN {
  $HTTP::Throwable::Role::Status::GatewayTimeout::AUTHORITY = 'cpan:STEVAN';
}
$HTTP::Throwable::Role::Status::GatewayTimeout::VERSION = '0.019';
use Moose::Role;

with(
    'HTTP::Throwable',
    'HTTP::Throwable::Role::BoringText',
);

sub default_status_code { 504 }
sub default_reason      { 'Gateway Timeout' }

no Moose::Role; 1;

=pod

=encoding UTF-8

=head1 NAME

HTTP::Throwable::Role::Status::GatewayTimeout - 504 Gateway Timeout

=head1 VERSION

version 0.019

=head1 DESCRIPTION

The server, while acting as a gateway or proxy, did not
receive a timely response from the upstream server specified
by the URI (e.g. HTTP, FTP, LDAP) or some other auxiliary
server (e.g. DNS) it needed to access in attempting to
complete the request.

=head1 AUTHORS

=over 4

=item *

Stevan Little <stevan.little@iinteractive.com>

=item *

Ricardo Signes <rjbs@cpan.org>

=back

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by Infinity Interactive, Inc..

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

__END__

# ABSTRACT: 504 Gateway Timeout

#pod =head1 DESCRIPTION
#pod
#pod The server, while acting as a gateway or proxy, did not
#pod receive a timely response from the upstream server specified
#pod by the URI (e.g. HTTP, FTP, LDAP) or some other auxiliary
#pod server (e.g. DNS) it needed to access in attempting to
#pod complete the request.
#pod

==> HTTP-Throwable-0.028.tar.gz: HTTP-Throwable-0.028/lib/HTTP/Throwable/Role/Status/GatewayTimeout.pm <==
package HTTP::Throwable::Role::Status::GatewayTimeout 0.028;
our $AUTHORITY = 'cpan:STEVAN';

use Moo::Role;

with(
    'HTTP::Throwable',
    'HTTP::Throwable::Role::BoringText',
);

sub default_status_code { 504 }
sub default_reason      { 'Gateway Timeout' }

no Moo::Role; 1;

=pod

=encoding UTF-8

=head1 NAME

HTTP::Throwable::Role::Status::GatewayTimeout - 504 Gateway Timeout

=head1 VERSION

version 0.028

=head1 DESCRIPTION

The server, while acting as a gateway or proxy, did not
receive a timely response from the upstream server specified
by the URI (e.g. HTTP, FTP, LDAP) or some other auxiliary
server (e.g. DNS) it needed to access in attempting to
complete the request.

=head1 PERL VERSION

This library should run on perls released even a long time ago.  It should work
on any version of perl released in the last five years.

Although it may work on older versions of perl, no guarantee is made that the
minimum required version will not be increased.  The version may be increased
for any reason, and there is no promise that patches will be accepted to lower
the minimum required perl.

=head1 AUTHORS

=over 4

=item *

Stevan Little <stevan.little@iinteractive.com>

=item *

Ricardo Signes <cpan@semiotic.systems>

=back

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by Infinity Interactive, Inc.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

__END__

# ABSTRACT: 504 Gateway Timeout

#pod =head1 DESCRIPTION
#pod
#pod The server, while acting as a gateway or proxy, did not
#pod receive a timely response from the upstream server specified
#pod by the URI (e.g. HTTP, FTP, LDAP) or some other auxiliary
#pod server (e.g. DNS) it needed to access in attempting to
#pod complete the request.
#pod
